@@ -92,9 +92,13 @@ strip_unapproved <- function(layers){
                         Rmark            = "GeomRmark",
                         point_swap       = "GeomPointSwap",
                         rect             = "GeomRect",
+                        polygon_closed   = "GeomPolygonClosed",
+                        hex_tern         = "GeomHexTern",
+                        tri_tern         = "GeomTriTern",
                         "GeomRasterAnnTern",
                         "GeomDl",
                         "GeomEncircle",
+                        "GeomCustomAnn",
                         mean_ellipse     = "GeomMeanEllipse",
                         text_viewport    = "GeomTextViewport",
                         label_viewport   = "GeomLabelViewport"
@@ -108,7 +112,9 @@ strip_unapproved <- function(layers){
                         sum              = "StatSum",
                         unique           = "StatUnique",
                         interpolate_tern = "StatInterpolateTern",
-                        mean_ellipse     = "StatMeanEllipse"
+                        mean_ellipse     = "StatMeanEllipse",
+                        hex_tern         = "StatHexTern",
+                        tri_tern         = "StatTriTern"
 )
 
 #LIST OF APPROVED POSITIONS
